==> rubygems_3.4.20.orig.tar.gz: rubygems-3.4.20/.github/ISSUE_TEMPLATE/rubygems-related-issue.md <==
---
name: "RubyGems related issue"
about: This template is intended for RubyGems specific related issues.
title: ''
labels: 'RubyGems'
assignees: ''

---

<!--

Thank you for contributing to the
[rubygems](https://github.com/rubygems/rubygems) repository, and specifically to
[RubyGems](https://guides.rubygems.org/).

-->

### Describe the problem as clearly as you can

<!--

Replace this with an explanation of the problem you are having. Be as much clear and precise as you can.

-->

### Did you try upgrading RubyGems?

<!--

Make sure you're using the latest version of both RubyGems by running `gem
update --system`.

It's likely that your issue has been fixed in recent versions, so just upgrading
might do the trick, and will also save us some time :)

-->

### Post steps to reproduce the problem

<!--

Fill this with a list of steps maintainers can follow to reproduce your issue.
Note that while you are seeing this issue in your computer, maintainers might
not see the same thing on theirs. There is a number of things that could
influence this:

* How your ruby is setup (OS package, from source, using a version manager).
* How RubyGems is configured.
* The version of each involved piece of software that you are using.
* ...

The more complete the steps to simulate your particular environment are, the
easier it will be for maintainers to reproduce your issue on their machines.

Ideally, we recommend you to set up the list of steps as a
[Dockerfile](https://docs.docker.com/get-started/). A Dockerfile provides a
neutral environment that should give the same results, no matter where it's run.

-->

### Which command did you run?

<!-- Replace this with the specific command that is causing trouble. -->

### What were you expecting to happen?

<!-- Replace this with the results you expected before running the command. -->

### What actually happened?

<!-- Replace this with the actual result you got. Paste the output of your command here. -->

### Run `gem env` and paste the output below

<!-- Replace this with the result of `gem env`. Don't forget to anonymize any private data! -->

==> rubygems-4.0.4.tar.gz: rubygems-4.0.4/.github/ISSUE_TEMPLATE/rubygems-related-issue.md <==
---
name: "RubyGems related issue"
about: This template is intended for RubyGems specific related issues.
title: ''
labels: 'RubyGems'
assignees: ''

---

<!--

Thank you for contributing to the
[rubygems](https://github.com/ruby/rubygems) repository, and specifically to
[RubyGems](https://guides.rubygems.org/).

-->

### Describe the problem as clearly as you can

<!--

Replace this with an explanation of the problem you are having. Be as much clear and precise as you can.

-->

### Did you try upgrading RubyGems?

<!--

Make sure you're using the latest version of both RubyGems by running `gem
update --system`.

It's likely that your issue has been fixed in recent versions, so just upgrading
might do the trick, and will also save us some time :)

-->

### Post steps to reproduce the problem

<!--

Fill this with a list of steps maintainers can follow to reproduce your issue.
Note that while you are seeing this issue in your computer, maintainers might
not see the same thing on theirs. There is a number of things that could
influence this:

* How your ruby is setup (OS package, from source, using a version manager).
* How RubyGems is configured.
* The version of each involved piece of software that you are using.
* ...

The more complete the steps to simulate your particular environment are, the
easier it will be for maintainers to reproduce your issue on their machines.

Ideally, we recommend you to set up the list of steps as a
[Dockerfile](https://docs.docker.com/get-started/). A Dockerfile provides a
neutral environment that should give the same results, no matter where it's run.

-->

### Which command did you run?

<!-- Replace this with the specific command that is causing trouble. -->

### What were you expecting to happen?

<!-- Replace this with the results you expected before running the command. -->

### What actually happened?

<!-- Replace this with the actual result you got. Paste the output of your command here. -->

### Run `gem env` and paste the output below

<!-- Replace this with the result of `gem env`. Don't forget to anonymize any private data! -->
